@@ -1,10 +1,12 @@
 #!/usr/bin/env perl
-use Mojo::Base -strict;
 
 use lib './';
 use lib './t';
 use lib './lib';
 use lib '../lib';
+use lib $ENV{'HOME'} . '/perl5/lib/perl5';
+
+use Mojo::Base -strict;
 
 # Disable Bonjour, IPv6 and libev
 BEGIN {
@@ -15,15 +17,10 @@ BEGIN {
 use Test::More tests => 9;
 
 use Mojolicious::Lite;
-use File::Basename;
 use Test::Mojo;
 
-my $module = basename __FILE__;
-
 # DOC renderer plugin
-plugin 'DOCRenderer' => {
-    module => $module,
-};
+plugin 'DOCRenderer';
 
 # app->start;
 my $t = Test::Mojo->new;
@@ -31,7 +28,7 @@ my $t = Test::Mojo->new;
 $t->get_ok('/doc')
     ->status_is(200)
     ->content_like(qr/It works!/);
-$t->get_ok("/doc/$module")
+$t->get_ok("/doc.txt")
     ->status_is(200)
     ->content_like(qr/It works!/);
 $t->get_ok("/doc/Mojolicious/Plugin/DOCRenderer")
